@@ -69,4 +69,4 @@ class XEventHandler(EventHandler):
 x = X()
 x.event_handler = XEventHandler()
 for i in range(100):
-    x.generate_event()
+    x.get_event_generator_function()
